@@ -4,7 +4,7 @@ from datetime import date
 from jsonclasses.types import Types
 from jsonclasses.fdef import FStore, FType
 from jsonclasses.mgraph import MGraph
-from inflection import underscore, camelize
+from inflection import camelize
 from .utils import (
     ref_field_key, ref_field_keys, ref_db_field_key, ref_db_field_keys
 )
