@@ -1,7 +1,6 @@
 from __future__ import annotations
-from typing import Union, TYPE_CHECKING
-from inflection import camelize
-from jsonclasses.fdef import FType
+from typing import TYPE_CHECKING
+from inflection import camelize, singularize
 if TYPE_CHECKING:
     from .pymongo_object import PymongoObject
 
@@ -29,7 +28,6 @@ def ref_db_field_key(key: str, cls: type[PymongoObject]) -> str:
 
 
 def ref_field_keys(key: str) -> str:
-    from inflection import singularize
     return singularize(key) + '_ids'
 
 
